#!/usr/bin/perl -w
#
#use strict;
#use Test::More;
#
#eval {
#	require Test::Kwalitee;
#	Test::Kwalitee->import();
#};
#
#plan( skip_all => "Test::Kwalitee not installed; skipping") if $@;
#
use Test::More skip_all => "temp disable author tests";

